[VOL-3396] Enabling AES encryption

Change-Id: Id48a76e8a05279a8d03b10d7d20e6944a77b3e47
diff --git a/pkg/mocks/mockTechprofile.go b/pkg/mocks/mockTechprofile.go
index a016b2c..f150190 100644
--- a/pkg/mocks/mockTechprofile.go
+++ b/pkg/mocks/mockTechprofile.go
@@ -185,9 +185,13 @@
 	return []*tp_pb.TrafficQueue{{}}
 }
 
-// GetGemportIDForPbit to mock techprofile GetGemportIDForPbit method
-func (m MockTechProfile) GetGemportIDForPbit(ctx context.Context, tp interface{}, Dir tp_pb.Direction, pbit uint32) uint32 {
-	return 0
+// GetGemportForPbit to mock techprofile GetGemportForPbit method
+func (m MockTechProfile) GetGemportForPbit(ctx context.Context, tpInst interface{}, Dir tp_pb.Direction, pbit uint32) interface{} {
+	return tp.IGemPortAttribute{
+		GemportID:     1,
+		PbitMap:       "0b11111111",
+		AesEncryption: "false",
+	}
 }
 
 // FindAllTpInstances to mock techprofile FindAllTpInstances method